class SocialRailsError(Exception):
    """Exception raised when the SocialRails API returns an error response."""

    def __init__(self, message: str, code: str = "unknown", status: int = 0):
        super().__init__(message)
        self.message = message
        self.code = code
        self.status = status

    def __repr__(self) -> str:
        return f"SocialRailsError(code={self.code!r}, status={self.status}, message={self.message!r})"
